@@ -67,10 +67,10 @@ int main (int argc, char *argv[])
           string = xstrdup("void");
         }
 
-        printf ("extern OilFunctionClass *oil_function_class_ptr_%s;\n",
+        printf ("OIL_EXPORT OilFunctionClass *oil_function_class_ptr_%s;\n",
             klass->name);
         printf ("typedef void (*_oil_type_%s)(%s);\n",klass->name,string);
-        printf ("#define oil_%s ((_oil_type_%s)(*(void **)oil_function_class_ptr_%s))\n",
+        printf ("#define oil_%s ((_oil_type_%s)(*(void(**)(void))oil_function_class_ptr_%s))\n",
             klass->name, klass->name, klass->name);
 
         oil_prototype_free (proto);
@@ -152,4 +152,3 @@ xstrdup (const char *s)
 
   return t;
 }
-
