@@ -6,4 +6,6 @@ void oil_random_alpha(void) {}
 void oil_random_argb(void) {}
 void oil_test_get_source_data(void) {}
 void oil_test_get_value(void) {}
+void oil_test_get_arg_post_n(void) {}
+void oil_test_get_arg_stride(void) {}
 
