@@ -33,33 +33,6 @@
 #include <liboil/simdpack/simdpack.h>
 #include <math.h>
 
-OIL_DEFINE_CLASS (diffsquaresum_f64,
-    "double *d_1, double *src1, int sstr1, double *src2, int sstr2, int n");
-
-static void
-diffsquaresum_f64_ref(double *dest, double *src1, int sstr1, double *src2,
-    int sstr2, int n)
-{
-	double sum = 0;
-	double errsum = 0;
-	double tmp;
-	double x;
-	int i;
-
-	for(i=0;i<n;i++){
-		x = OIL_GET(src1, i*sstr1, double) -
-                  OIL_GET(src2, i*sstr2, double);
-		x = x*x;
-		tmp = sum;
-		sum += x;
-		errsum += (tmp - sum) + x;
-	}
-
-	*dest = sum + errsum;
-}
-
-OIL_DEFINE_IMPL_REF (diffsquaresum_f64_ref, diffsquaresum_f64);
-
 static void
 diffsquaresum_f64_i10_simple(double *dest, double *src1, int sstr1, double *src2,
     int sstr2, int n)
